.. _sardana-users-guide-index:

============
User's Guide
============

.. toctree::
    :maxdepth: 2
    
    Overview <overview>
    Getting started <getting_started/index>
    Spock <spock>
    Scans <scan>
    Standard macro catalog <standard_macro_catalog>
    Screenshots <screenshots>
    FAQ <faq>

